"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*---------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/
const chai_1 = require("chai");
const util_1 = require("./util");
describe('namespacing', () => {
    let client;
    let ns;
    beforeEach(async () => {
        client = await util_1.createTestClientAndKeys();
        ns = client.namespace('user1/');
    });
    afterEach(async () => await util_1.tearDownTestClient(client));
    const assertEqualInNamespace = async (key, value) => {
        chai_1.expect(await ns.get(key)).to.equal(value);
        chai_1.expect(await client.get(`user1/${key}`)).to.equal(value);
    };
    it('puts and gets values in the namespace', async () => {
        await ns.put('foo').value('');
        await assertEqualInNamespace('foo', '');
        chai_1.expect(await ns.getAll().strings()).to.deep.equal({ foo: '' });
    });
    it('deletes values in the namespace', async () => {
        await ns.put('foo1').value('');
        await ns.put('foo2').value('');
        await ns.delete().key('foo1');
        chai_1.expect(await ns.getAll().strings()).to.deep.equal({ foo2: '' });
        await ns.delete().all();
        chai_1.expect(await ns.getAll().strings()).to.deep.equal({});
        chai_1.expect(await client.getAll().keys()).to.have.length.greaterThan(0);
    });
    it('contains leases in the namespace', async () => {
        const lease = ns.lease(100);
        await lease.put('leased').value('');
        await assertEqualInNamespace('leased', '');
        await lease.revoke();
    });
    it('contains locks in the namespace', async () => {
        const lock = ns.lock('mylock');
        await lock.acquire();
        chai_1.expect(await ns.get('mylock')).to.not.be.null;
        chai_1.expect(await client.get('user1/mylock')).to.not.be.null;
        await lock.release();
    });
    it('runs a simple if', async () => {
        await ns.put('foo1').value('potatoes');
        await ns.if('foo1', 'Value', '==', 'potatoes').then(ns.put('foo1').value('tomatoes')).commit();
        await assertEqualInNamespace('foo1', 'tomatoes');
    });
});
//# sourceMappingURL=namespacing.test.js.map