"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*---------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/
const chai_1 = require("chai");
const util_1 = require("./util");
describe('transactions', () => {
    let client;
    beforeEach(async () => (client = await util_1.createTestClientAndKeys()));
    afterEach(async () => await util_1.tearDownTestClient(client));
    it('runs a simple if', async () => {
        await client.if('foo1', 'Value', '==', 'bar1').then(client.put('foo1').value('bar2')).commit();
        chai_1.expect(await client.get('foo1').string()).to.equal('bar2');
    });
    it('runs consequents', async () => {
        await client
            .if('foo1', 'Value', '==', 'bar1')
            .then(client.put('foo1').value('bar2'))
            .else(client.put('foo1').value('bar3'))
            .commit();
        chai_1.expect(await client.get('foo1').string()).to.equal('bar2');
    });
    it('runs multiple clauses and consequents', async () => {
        const result = await client
            .if('foo1', 'Value', '==', 'bar1')
            .and('foo2', 'Value', '==', 'wut')
            .then(client.put('foo1').value('bar2'))
            .else(client.put('foo1').value('bar3'), client.get('foo2'))
            .commit();
        chai_1.expect(result.responses[1].response_range.kvs[0].value.toString()).to.equal('bar2');
        chai_1.expect(await client.get('foo1').string()).to.equal('bar3');
    });
});
//# sourceMappingURL=transactions.test.js.map