import { Etcd3, IOptions, Namespace } from '..';
export declare const enum TrafficDirection {
    ToEtcd = 0,
    FromEtcd = 1
}
export declare const etcdVersion: string;
/**
 * Proxy is a TCP proxy for etcd, used so that we can simulate network failures
 * and disruptions in a cross-platform manner (i.e no reliance on tcpkill
 * or ip link)
 */
export declare class Proxy {
    isActive: boolean;
    connections: Array<{
        end(): void;
    }>;
    private server;
    private host;
    private port;
    private enabledDataFlows;
    /**
     * activate creates the proxy server.
     */
    activate(): Promise<void>;
    /**
     * suspend temporarily shuts down the server, but does not 'deactivate' the
     * proxy; new connections will still try to hit it. Can be restored with
     * resume().
     */
    suspend(): void;
    /**
     * Starts up a previously stopped server.
     */
    unsuspend(): void;
    /**
     * Disables data flowing in one direction on the connection.
     */
    pause(direction: TrafficDirection): void;
    /**
     * Reenables data flow on the connection.
     */
    resume(direction: TrafficDirection): void;
    /**
     * Destroys a previously-active proxy server.
     */
    deactivate(): Promise<void>;
    /**
     * Returns the address the server is listening on.
     */
    address(): string;
    private handleIncoming;
}
export declare const proxy: Proxy;
/**
 * Returns the host to test against.
 */
export declare function getHost(): string;
/**
 * Returns etcd options to use for connections.
 */
export declare function getOptions(defaults?: Partial<IOptions>): IOptions;
/**
 * Returns a promise that throws if the promise is resolved or rejected with
 * something other than the provided constructor
 */
export declare function expectReject(promise: Promise<any>, err: new (message: string) => Error): Promise<void>;
/**
 * Creates a new test etcd client.
 */
export declare function createTestClient(): Etcd3;
/**
 * Creates an etcd client with the default options and seeds some keys.
 */
export declare function createTestClientAndKeys(): Promise<Etcd3>;
/**
 * Creates test keys in the given namespace.
 */
export declare function createTestKeys(client: Namespace): Promise<void>;
/**
 * Destroys the etcd client and wipes all keys.
 */
export declare function tearDownTestClient(client: Etcd3): Promise<void>;
/**
 * Sets up authentication for the server.
 */
export declare function setupAuth(client: Etcd3): Promise<void>;
/**
 * Removes authentication previously added with `setupAuth`
 */
export declare function removeAuth(client: Etcd3): Promise<void>;
export declare const isAtLeastVersion: (version: string) => boolean;
export declare const atAtMostVersion: (version: string) => boolean;
export declare const unmockedDelay: (duration: number) => Promise<unknown>;
